@@ -10,7 +10,6 @@
 #include "compositing_manager.h"
 #include "player_engine.h"
 #include "hwdec_probe.h"
-#include "sysutils.h"
 
 #ifndef _LIBDMR_
 #include "dmr_settings.h"
@@ -368,6 +367,12 @@ mpv_handle *MpvProxy::mpv_init()
         QFileInfo X100GPU("/dev/x100gpu");
         QFileInfo X100VPU("/dev/vxd0");
         QFileInfo mtfi("/dev/mtgpu.0");
+        QFile cpuInfo("/proc/cpuinfo");
+        bool isVirtualMachine = false;
+        if (cpuInfo.open(QIODevice::ReadOnly | QIODevice::Text)) {
+            isVirtualMachine = cpuInfo.readAll().contains("hypervisor");
+            cpuInfo.close();
+        }
         if (fi.exists() || jmfi.exists()) { //2.1.1景嘉微
             QDir sdir(QLibraryInfo::location(QLibraryInfo::LibrariesPath) +QDir::separator() +"mwv206"); //判断是否安装核外驱动
             QDir jmdir(QLibraryInfo::location(QLibraryInfo::LibrariesPath) +QDir::separator() +"mwv207");
@@ -394,8 +399,12 @@ mpv_handle *MpvProxy::mpv_init()
         }  else if (X100GPU.exists() && X100VPU.exists()) {
             my_set_property(m_handle, "hwdec", "ftomx-copy");
             my_set_property(m_handle, "vo", "gpu");
+            m_sInitVo = "gpu";
         } else if (CompositingManager::get().isOnlySoftDecode()) {//2.1.3 鲲鹏920 || 曙光+英伟达 || 浪潮
             my_set_property(pHandle, "hwdec", "no");
+        } else if (isVirtualMachine) {
+            my_set_property(m_handle, "vo", "x11");
+            m_sInitVo = "x11";
         } else { //2.2非特殊硬件
             my_set_property(pHandle, "hwdec", "auto");
         }
@@ -456,16 +465,23 @@ mpv_handle *MpvProxy::mpv_init()
             process.waitForFinished();
             process.waitForReadyRead();
 
-            QString comStr = process.readAllStandardOutput();
-            comStr = comStr.right(3).left(2);
-            int version = comStr.toInt();
-            if (version >= 10) {
-                my_set_property(pHandle, "vo", "vaapi");
-                my_set_property(pHandle, "hwdec", "vaapi");
-                m_sInitVo = "vaapi";
+            QString error = process.readAllStandardError();
+            if (error.isEmpty()) {
+                QString comStr = process.readAllStandardOutput();
+                comStr = comStr.right(3).left(2);
+                int version = comStr.toInt();
+                if (version >= 10) {
+                    my_set_property(pHandle, "vo", "vaapi");
+                    my_set_property(pHandle, "hwdec", "vaapi");
+                    m_sInitVo = "vaapi";
+                } else {
+                    my_set_property(pHandle, "vo", "gpu");
+                    m_sInitVo = "gpu";
+                }
             } else {
-                my_set_property(pHandle, "vo", "gpu");
-                m_sInitVo = "gpu";
+                my_set_property(pHandle, "vo", "x11,xv");
+                my_set_property(pHandle, "hwdec", "vaapi");
+                m_sInitVo = "x11,xv";
             }
         }
 #endif
@@ -877,6 +893,10 @@ void MpvProxy::handle_mpv_events()
                         << "codec: " << my_get_property(m_handle, "video-codec")
                         << "format: " << my_get_property(m_handle, "video-format");
             }
+#if MPV_CLIENT_API_VERSION > MPV_MAKE_VERSION(2,0)
+            updatePlayingMovieInfo();
+            emit tracksChanged();
+#endif
 //            if (!m_bIsJingJia) {
 //#ifdef __mips__
 //                qInfo() << "MPV_EVENT_FILE_LOADED __mips__";
@@ -1350,6 +1370,10 @@ void MpvProxy::refreshDecode()
             } else { //2.2.2 非特殊硬件 + 非特殊格式
                  my_set_property(m_handle, "hwdec","auto");
                 //bIsCanHwDec ? my_set_property(m_handle, "hwdec", canHwTypes.join(',')) : my_set_property(m_handle, "hwdec", "no");
+#if defined (__sw_64__)
+        //Synchronously modify the video output of the SW platform vdpau(powered by zhangfl)
+        my_set_property(m_handle, "hwdec", "vdpau");
+#endif
             }
         }
 
@@ -2080,6 +2104,8 @@ void MpvProxy::setProperty(const QString &sName, const QVariant &val)
         QObject::setProperty("dmrhwdec-switch", val);
     } else {
         my_set_property(m_handle, sName.toUtf8().data(), val);
+        if (sName == "vo")
+            m_sInitVo = val.toString();
     }
 }
 
