@@ -1,6 +1,7 @@
 // SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef _DMR_PLATFPRM_MAIN_WINDOW_H
 #define _DMR_PLATFPRM_MAIN_WINDOW_H
 
@@ -14,9 +15,13 @@
 #include <DPushButton>
 #include <DFloatingMessage>
 #include <QDBusAbstractInterface>
-#include <QtX11Extras/QX11Info>
-#include <QDBusInterface>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#include <QtX11Extras/QX11Info>
+#else
+#include <QtGui/private/qtx11extras_p.h>
+#include <QtGui/private/qtguiglobal_p.h>
+#endif
 #include "widgets/titlebar.h"
 #include "platform/platform_animationlabel.h"
 #include "diskcheckthread.h"
@@ -138,27 +143,8 @@ public:
         m_pTextLabel->setFixedHeight(25);
         m_pTextLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
 
-        m_pViewBtn = new DPushButton(this);
-        m_pViewBtn->setFixedSize(52, 28);
-        m_pViewBtn->setText(tr("View"));
-        m_pViewBtn->setFocusPolicy(Qt::NoFocus);
-        m_pViewBtn->hide();
-
-        connect(m_pViewBtn, &DPushButton::clicked, this, [=]{
-            QUrl displayUrl = QUrl::fromLocalFile(m_imgPath);
-            QDBusInterface interface(QStringLiteral("org.freedesktop.FileManager1"),
-                                         QStringLiteral("/org/freedesktop/FileManager1"),
-                                         QStringLiteral("org.freedesktop.FileManager1"));
-            if (interface.isValid()) {
-                QStringList list;
-                list << displayUrl.toString();
-                interface.call("ShowItems", list, "");
-            }
-        });
-
         mainLayout->addWidget(m_pIconBtn);
         mainLayout->addWidget(m_pTextLabel);
-        mainLayout->addWidget(m_pViewBtn);
 
         m_pTimer->setInterval(4000);
         m_pTimer->setSingleShot(true);
@@ -174,13 +160,6 @@ public:
     {
         m_pTextLabel->setText(str);
     }
-    void setImgPath(const QString &path)
-    {
-        m_imgPath = path;
-        m_pViewBtn->show();
-    }
-signals:
-    void viewScreenShot();
 protected:
     void showEvent(QShowEvent *event)
     {
@@ -219,8 +198,6 @@ private:
     QTimer *m_pTimer {nullptr};
     DIconButton *m_pIconBtn {nullptr};
     DLabel *m_pTextLabel{nullptr};
-    DPushButton *m_pViewBtn{nullptr};
-    QString m_imgPath;
 };
 
 /**
@@ -368,6 +345,9 @@ public slots:
      * @param 影片路径
      */
     void play(const QList<QString> &listFiles);
+        /**
+     * @brief 该函数主要设置 m_pToolbox 和 m_pPlaylist 的Geometry，在(初始化)、(紧凑/正常终模式之间切换时)以及(全屏/非全屏模式之间切换时）调用
+     */
     void updateProxyGeometry();
     void suspendToolsWindow();
     void resumeToolsWindow();
@@ -407,6 +387,10 @@ public slots:
      * @brief 显示是否在缓冲中
      */
     void slotUrlpause(bool bStatus);
+    /**
+     * @brief 根据字体大小改变显示
+     */
+    void slotFontChanged(const QFont &font);
     /**
      * @brief 改变静音状态
      */
@@ -419,7 +403,7 @@ public slots:
      * @brief 音量改变槽函数
      */
     void slotVolumeChanged(int nVolume);
-    void slotWMChanged(QString msg);
+    void slotWMChanged();
     /**
      * @brief slotUpdateMircastState 更新投屏状态槽函数
      * @param state 投屏状态
@@ -509,7 +493,7 @@ private:
     void readSinkInputPath();
     void setAudioVolume(int);
     void setMusicMuted(bool bMuted);
-    void popupAdapter(QIcon, QString, QString path = QString());
+    void popupAdapter(QIcon, QString);
     //void setHwaccelMode(const QVariant &value = -1);
     //Limit video to mini mode size
     void LimitWindowize();
@@ -528,13 +512,14 @@ private:
 
 private:
     Platform_MessageWindow *m_pPopupWid;                     ///截图提示窗口
+    QLabel *m_pFullScreenTimeLable;                 ///全屏时右上角的影片进度
     QHBoxLayout *m_pFullScreenTimeLayout;           ///右上角的影片进度框布局器
     Titlebar *m_pTitlebar;                          ///标题栏
-    FullScreenTitlebar *m_fsTitlebar;               ///全屏标题栏
     Platform_ToolboxProxy *m_pToolbox;                       ///工具栏
     Platform_PlaylistWidget *m_pPlaylist;                    ///播放列表
     PlayerEngine *m_pEngine;                        ///播放引擎
     Platform_AnimationLabel *m_pAnimationlable;              ///点击暂停和播放时动画
+    Platform_MovieProgressIndicator *m_pProgIndicator;       ///全屏时右上角的系统时间
     QList<QPair<QImage, qint64>> m_listBurstShoots; ///存储连拍截图
     bool m_bInBurstShootMode;                       ///是否处于截图状态
     bool m_bPausedBeforeBurst;                      ///截图时暂停播放
@@ -604,7 +589,9 @@ private:
     qint64 m_nFullscreenTime;                         ///全屏操作间隔时间
     QDBusInterface *m_pWMDBus {nullptr};              ///窗口特效dbus接口
     bool m_bIsWM {true};                              ///是否开启窗口特效
-    bool m_bMaximized;                                ///全屏前最大化窗口记录        
+    bool m_bMaximized;                                ///全屏前最大化窗口记录
+    bool m_bLocked{true};
+    DSettingsDialog *m_pDSettingDilog{nullptr};
 };
 };
 
