@@ -10,6 +10,9 @@
 #ifndef _LIBDMR_
 #include "options.h"
 #endif
+#ifdef DTKCORE_CLASS_DConfigFile
+#include <DConfig>
+#endif
 
 #include <iostream>
 #include <unistd.h>
@@ -61,7 +64,9 @@ public:
     Platform check()
     {
         QProcess uname;
-        uname.start("uname -m");
+        uname.setProgram("uname");
+        uname.setArguments({"-m"});
+        uname.start();
         if (uname.waitForStarted()) {
             if (uname.waitForFinished()) {
                 auto data = uname.readAllStandardOutput();
@@ -93,6 +98,9 @@ public:
                     _pf = Platform::Arm64;
                 }
             }
+        } else {
+            QString error = uname.readAllStandardError();
+            qWarning() << error;
         }
 
         return _pf;
@@ -153,17 +161,17 @@ CompositingManager::CompositingManager()
         m_setSpecialControls = detect550Series();
     }
 
-//    bool isI915 = false;
-//    for (int id = 0; id <= 10; id++) {
-//        if (!QFile::exists(QString("/sys/class/drm/card%1").arg(id))) break;
-//        if (is_device_viable(id)) {
-//            vector<string> drivers = {"i915"};
-//            isI915 = is_card_exists(id, drivers);
-//            break;
-//        }
-//    }
-//    if (isI915) qInfo() << "is i915!";
-//    m_bZXIntgraphics = isI915 ? isI915 : m_bZXIntgraphics;
+   bool isI915 = false;
+   for (int id = 0; id <= 10; id++) {
+       if (!QFile::exists(QString("/sys/class/drm/card%1").arg(id))) break;
+       if (is_device_viable(id)) {
+           vector<string> drivers = {"i915", "arise"};
+           isI915 = is_card_exists(id, drivers);
+           break;
+       }
+   }
+   if (isI915) qInfo() << "is i915!";
+   m_bZXIntgraphics = isI915 ? isI915 : m_bZXIntgraphics;
 
     if (dmr::utils::check_wayland_env()) {
         _composited = true;
@@ -212,31 +220,54 @@ CompositingManager::CompositingManager()
     //TODO: 临时处理方案
     _composited = true;
 #if defined (_MOVIE_USE_)
-    //TODO
-    // QGSettings gsettings("com.deepin.deepin-movie", "/com/deepin/deepin-movie/");
-    // QString aa = gsettings.get("composited").toString();
-    // if ((gsettings.get("composited").toString() == "DisableComposited"
-    //         || gsettings.get("composited").toString() == "EnableComposited")) {
-    //     if (gsettings.keys().contains("composited")) {
-    //         if (gsettings.get("composited").toString() == "DisableComposited") {
-    //             _composited = false;
-    //         } else if (gsettings.get("composited").toString() == "EnableComposited") {
-    //             _composited = true;
-    //         }
-    //     }
-    // } else {
-    //     if (_platform == Platform::X86) {
-    //         if (m_bZXIntgraphics) {
-    //             _composited = false;
-    //         } else {
-    //             _composited = true;
-    //         }
-    //     } else {
-    //         if (_platform == Platform::Arm64 && isDriverLoaded)
-    //             m_bHasCard = true;
-    //         _composited = false;
-    //     }
-    // }
+#ifdef DTKCORE_CLASS_DConfigFile
+    //需要查询是否支持特殊特殊机型打开迷你模式，例如hw机型
+    DConfig *dconfig = DConfig::create("org.deepin.movie","org.deepin.movie.minimode");
+    if(dconfig && dconfig->isValid() && dconfig->keyList().contains("compositedHandling")){
+        QString compositedHandling = dconfig->value("compositedHandling").toString();
+        if (compositedHandling == "DisableComposited") {
+            _composited = false;
+        } else if (compositedHandling == "EnableComposited") {
+            _composited = true;
+        } else {
+            if (_platform == Platform::X86) {
+                if (m_bZXIntgraphics) {
+                    _composited = false;
+                } else {
+                    _composited = true;
+                }
+            } else {
+                if (_platform == Platform::Arm64 && isDriverLoaded)
+                    m_bHasCard = true;
+                _composited = false;
+            }
+        }
+    } else {
+        if (_platform == Platform::X86) {
+            if (m_bZXIntgraphics) {
+                _composited = false;
+            } else {
+                _composited = true;
+            }
+        } else {
+            if (_platform == Platform::Arm64 && isDriverLoaded)
+                m_bHasCard = true;
+            _composited = false;
+        }
+    }
+#else
+    if (_platform == Platform::X86) {
+        if (m_bZXIntgraphics) {
+            _composited = false;
+        } else {
+            _composited = true;
+        }
+    } else {
+        if (_platform == Platform::Arm64 && isDriverLoaded)
+            m_bHasCard = true;
+        _composited = false;
+    }
+#endif
 #endif
 
     //针对jm显卡适配
@@ -604,7 +635,18 @@ bool CompositingManager::isDriverLoadedCorrectly()
 #endif
 #endif
 
-    QString xorglog = QString("/var/log/Xorg.%1.log").arg(QGuiApplication::primaryScreen()->name().split("-").last());
+    QString xorglog;
+    if (_platform == Platform::Mips) {
+        QDir logDir("/var/log/");
+        QStringList filters;
+        filters << "Xorg.*.log";
+        QStringList xorglogs = logDir.entryList(filters, QDir::Files);
+        if (xorglogs.isEmpty())
+            return false;
+        xorglog = xorglogs.last();
+    } else {
+        xorglog = QString("/var/log/Xorg.%1.log").arg(QGuiApplication::primaryScreen()->name().split("-").last());
+    }
     qInfo() << "check " << xorglog;
     QFile f(xorglog);
     if (!f.open(QFile::ReadOnly)) {
