@@ -12,19 +12,17 @@
 #include "dvd_utils.h"
 #include "compositing_manager.h"
 #include "gstutils.h"
+#include "sysutils.h"
 
 #include <QSvgRenderer>
-#include <DGuiApplicationHelper>
 
 #include <random>
-#include <libffmpegthumbnailer/videothumbnailerc.h>
 extern "C" {
 #include <libavcodec/avcodec.h>
 #include <libavformat/avformat.h>
 #include <libavutil/dict.h>
 #include <libavutil/avutil.h>
 }
-DWIDGET_USE_NAMESPACE
 
 typedef int (*mvideo_avformat_open_input)(AVFormatContext **ps, const char *url, AVInputFormat *fmt, AVDictionary **options);
 typedef int (*mvideo_avformat_find_stream_info)(AVFormatContext *ic, AVDictionary **options);
@@ -36,23 +34,8 @@ typedef AVCodec *(*mvideo_avcodec_find_decoder)(enum AVCodecID id);
 typedef const char *(*mvideo_av_get_media_type_string)(enum AVMediaType media_type);
 typedef AVCodecContext *(*mvideo_avcodec_alloc_context3)(const AVCodec *codec);
 typedef int (*mvideo_avcodec_parameters_to_context)(AVCodecContext *codec, const AVCodecParameters *par);
-
-video_thumbnailer *m_video_thumbnailer = nullptr;
-image_data *m_image_data = nullptr;
-
-typedef video_thumbnailer *(*mvideo_thumbnailer)();
-typedef void (*mvideo_thumbnailer_destroy)(video_thumbnailer *thumbnailer);
-/* create image_data structure */
-typedef image_data *(*mvideo_thumbnailer_create_image_data)(void);
-/* destroy image_data structure */
-typedef void (*mvideo_thumbnailer_destroy_image_data)(image_data *data);
-typedef int (*mvideo_thumbnailer_generate_thumbnail_to_buffer)(video_thumbnailer *thumbnailer, const char *movie_filename, image_data *generated_image_data);
-
-mvideo_thumbnailer m_mvideo_thumbnailer = nullptr;
-mvideo_thumbnailer_destroy m_mvideo_thumbnailer_destroy = nullptr;
-mvideo_thumbnailer_create_image_data m_mvideo_thumbnailer_create_image_data = nullptr;
-mvideo_thumbnailer_destroy_image_data m_mvideo_thumbnailer_destroy_image_data = nullptr;
-mvideo_thumbnailer_generate_thumbnail_to_buffer m_mvideo_thumbnailer_generate_thumbnail_to_buffer = nullptr;
+typedef int (*mvideo_avcodec_open2)(AVCodecContext *avctx, const AVCodec *codec, AVDictionary **options);
+typedef void (*mvideo_avcodec_free_context)(AVCodecContext **avctx);
 
 
 mvideo_avformat_open_input g_mvideo_avformat_open_input = nullptr;
@@ -65,6 +48,8 @@ mvideo_avcodec_find_decoder g_mvideo_avcodec_find_decoder = nullptr;
 mvideo_av_get_media_type_string g_mvideo_av_get_media_type_string = nullptr;
 mvideo_avcodec_alloc_context3 g_mvideo_avcodec_alloc_context3 = nullptr;
 mvideo_avcodec_parameters_to_context g_mvideo_avcodec_parameters_to_context = nullptr;
+mvideo_avcodec_open2 g_mvideo_avcodec_open2 = nullptr;
+mvideo_avcodec_free_context g_mvideo_avcodec_free_context = nullptr;
 
 namespace dmr {
 QDataStream &operator<< (QDataStream &st, const MovieInfo &mi)
@@ -331,6 +316,15 @@ struct MovieInfo PlaylistModel::parseFromFile(const QFileInfo &fi, bool *ok)
         } else {
             mi.proportion = 0;
         }
+
+        AVCodecContext *codec_context = g_mvideo_avcodec_alloc_context3(NULL);
+        g_mvideo_avcodec_parameters_to_context(codec_context, video_dec_ctx);
+        AVCodec *videoCodec = g_mvideo_avcodec_find_decoder(video_dec_ctx->codec_id);
+        if (g_mvideo_avcodec_open2(codec_context, videoCodec, 0) > 0) {
+            //用唯一的文件名绑定对应视频的对应pix_fmt值
+            setProperty(fi.filePath().toUtf8(), codec_context->pix_fmt);
+        }
+        g_mvideo_avcodec_free_context(&codec_context);
     }
     if (audioRet >= 0) {
         int audio_stream_index = -1;
@@ -356,8 +350,13 @@ struct MovieInfo PlaylistModel::parseFromFile(const QFileInfo &fi, bool *ok)
     mi.resolution = QString("%1x%2").arg(mi.width).arg(mi.height);
     mi.title = fi.fileName(); //FIXME this
     mi.filePath = fi.canonicalFilePath();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     qInfo() << __func__ << "created:" << fi.created() << "       toString:" << fi.created().toString();
     mi.creation = fi.created().toString();
+#else
+    qInfo() << __func__ << "created:" << fi.birthTime() << "       toString:" << fi.birthTime().toString();
+    mi.creation = fi.birthTime().toString();
+#endif
     mi.fileSize = fi.size();
     mi.fileType = fi.suffix();
 #ifdef _MOVIE_USE_
@@ -433,7 +432,14 @@ void PlaylistModel::slotStateChanged()
     case PlayerEngine::Idle:
         if (!_userRequestingItem) {
             stop();
-            playNext(false);
+            //WINID方式渲染结束时，保证gpu渲染资源的正常释放与切换，延时5ms执行下部视频的播放
+            if(!CompositingManager::get().composited()) {
+                QTimer::singleShot(5, [=]() {
+                    playNext(false);
+                });
+            } else {
+                playNext(false);
+            }
         }
         break;
     }
@@ -467,26 +473,10 @@ PlaylistModel::PlaylistModel(PlayerEngine *e)
 #endif
 }
 
-QString PlaylistModel::libPath(const QString &strlib)
-{
-    QDir  dir;
-    QString path  = QLibraryInfo::location(QLibraryInfo::LibrariesPath);
-    dir.setPath(path);
-    QStringList list = dir.entryList(QStringList() << (strlib + "*"), QDir::NoDotAndDotDot | QDir::Files); //filter name with strlib
-    if (list.contains(strlib)) {
-        return strlib;
-    } else {
-        list.sort();
-    }
-    if (list.size()>0)
-        return list.last();
-    else
-        return QString();
-}
 
 void PlaylistModel::initThumb()
 {
-    QLibrary library(CompositingManager::libPath("libffmpegthumbnailer.so"));
+    QLibrary library(SysUtils::libPath("libffmpegthumbnailer.so"));
     m_mvideo_thumbnailer = (mvideo_thumbnailer) library.resolve("video_thumbnailer_create");
     m_mvideo_thumbnailer_destroy = (mvideo_thumbnailer_destroy) library.resolve("video_thumbnailer_destroy");
     m_mvideo_thumbnailer_create_image_data = (mvideo_thumbnailer_create_image_data) library.resolve("video_thumbnailer_create_image_data");
@@ -510,9 +500,9 @@ void PlaylistModel::initThumb()
 
 void PlaylistModel::initFFmpeg()
 {
-    QLibrary avcodecLibrary(CompositingManager::libPath("libavcodec.so"));
-    QLibrary avformatLibrary(CompositingManager::libPath("libavformat.so"));
-    QLibrary avutilLibrary(CompositingManager::libPath("libavutil.so"));
+    QLibrary avcodecLibrary(SysUtils::libPath("libavcodec.so"));
+    QLibrary avformatLibrary(SysUtils::libPath("libavformat.so"));
+    QLibrary avutilLibrary(SysUtils::libPath("libavutil.so"));
 
     g_mvideo_avformat_open_input = (mvideo_avformat_open_input) avformatLibrary.resolve("avformat_open_input");
     g_mvideo_avformat_find_stream_info = (mvideo_avformat_find_stream_info) avformatLibrary.resolve("avformat_find_stream_info");
@@ -524,6 +514,8 @@ void PlaylistModel::initFFmpeg()
     g_mvideo_av_get_media_type_string = (mvideo_av_get_media_type_string) avutilLibrary.resolve("av_get_media_type_string");
     g_mvideo_avcodec_alloc_context3 = (mvideo_avcodec_alloc_context3) avcodecLibrary.resolve("avcodec_alloc_context3");
     g_mvideo_avcodec_parameters_to_context = (mvideo_avcodec_parameters_to_context) avcodecLibrary.resolve("avcodec_parameters_to_context");
+    g_mvideo_avcodec_open2 = (mvideo_avcodec_open2)(avcodecLibrary.resolve("avcodec_open2"));
+    g_mvideo_avcodec_free_context = (mvideo_avcodec_free_context)(avcodecLibrary.resolve("avcodec_free_context"));
 
     m_initFFmpeg = true;
 }
@@ -1400,7 +1392,7 @@ bool PlaylistModel::getMusicPix(const QFileInfo &fi, QPixmap &rImg)
         return false;
     }
 
-    QLibrary library(CompositingManager::libPath("libavformat.so"));
+    QLibrary library(SysUtils::libPath("libavformat.so"));
     mvideo_avformat_open_input g_mvideo_avformat_open_input_temp = (mvideo_avformat_open_input) library.resolve("avformat_open_input");
     mvideo_avformat_close_input g_mvideo_avformat_close_input = (mvideo_avformat_close_input) library.resolve("avformat_close_input");
     mvideo_avformat_find_stream_info g_mvideo_avformat_find_stream_info_temp = (mvideo_avformat_find_stream_info) library.resolve("avformat_find_stream_info");
@@ -1675,7 +1667,13 @@ MovieInfo MovieInfo::parseFromFile(const QFileInfo &fi, bool *ok)
     mi.resolution = QString("%1x%2").arg(mi.width).arg(mi.height);
     mi.title = fi.fileName(); //FIXME this
     mi.filePath = fi.canonicalFilePath();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    qInfo() << __func__ << "created:" << fi.created() << "       toString:" << fi.created().toString();
     mi.creation = fi.created().toString();
+#else
+    qInfo() << __func__ << "created:" << fi.birthTime() << "       toString:" << fi.birthTime().toString();
+    mi.creation = fi.birthTime().toString();
+#endif
     mi.fileSize = fi.size();
     mi.fileType = fi.suffix();
 
