@@ -13,7 +13,6 @@
 #include "utils.h"
 #include "movieinfo_dialog.h"
 #include "tip.h"
-#include "toolbutton.h"
 
 #include <DApplication>
 #include <dimagebutton.h>
@@ -47,7 +46,11 @@ protected:
             tip->adjustSize();
             tip->raise();
             QPoint pos = he->globalPos() + QPoint{0, 10};
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             int dw = qApp->desktop()->availableGeometry(item).width();
+#else
+            int dw = QGuiApplication::primaryScreen()->availableGeometry().width();
+#endif
             if (pos.x() + tip->width() > dw) {
                 pos.rx() = dw - tip->width();
             }
@@ -86,6 +89,7 @@ public:
         _thumb = nullptr;
         m_pSvgWidget = nullptr;
         setProperty("PlayItemThumb", "true");
+        //setState(ItemState::Normal);
         setFrameShape(QFrame::NoFrame);
         this->setObjectName(PLAYITEM_WIDGET);
         auto kd = "local";
@@ -102,27 +106,57 @@ public:
         _play = QPixmap(":/resources/icons/dark/normal/film-top.svg");
         _play.setDevicePixelRatio(qApp->devicePixelRatio());
 
-        setFixedSize(324, 40);
-        QHBoxLayout *l = new QHBoxLayout(this);
-        l->setContentsMargins(10, 0, 0, 0);
-        l->setSpacing(0);
+        setFixedSize(_playlist->width() - 230, 36);
+        auto *l = new QHBoxLayout(this);
+        l->setContentsMargins(17, 0, 0, 0);
+        l->setSpacing(10);
         setLayout(l);
 
         _index = new DLabel(this);
         DFontSizeManager::instance()->bind(_index, DFontSizeManager::T9);
         _index->setText(QString::number(index + 1));
-        _index->setFixedWidth(21);
+        _index->setFixedWidth(22);
         l->addWidget(_index);
+
+        if (_pif.thumbnail.isNull() && _pif.thumbnail_dark.isNull()) {
+            if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
+                m_pSvgWidget = new QSvgWidget(QString(":/resources/icons/music-dark.svg"), this);
+            } else {
+                m_pSvgWidget = new QSvgWidget(QString(":/resources/icons/music-light.svg"), this);
+            }
+            m_pSvgWidget->setFixedSize(42, 24);
+        } else {
+            if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
+                _thumb = new ListPic(_pif.thumbnail_dark.scaled(QSize(42, 24)), this);
+            } else {
+                _thumb = new ListPic(_pif.thumbnail.scaled(QSize(42, 24)), this);
+            }
+        }
+
+        if (_thumb) {
+            l->addWidget(_thumb);
+        } else {
+            l->addWidget(m_pSvgWidget);
+        }
         QObject::connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &PlayItemWidget::slotThemeTypeChanged);
 
+
+        auto *vl = new QHBoxLayout;
+        vl->setContentsMargins(0, 0, 0, 0);
+        vl->setSpacing(0);
+        l->addLayout(vl);
+
+//        vl->addStretch();
+
         _name = new DLabel(this);
         _name->setProperty("Name", true);
         _name->setFrameShape(QFrame::NoFrame);
         _name->setTextInteractionFlags(Qt::NoTextInteraction);
+        _name->setFixedWidth(width() - 180);
         _name->installEventFilter(this);
         _name->setAutoFillBackground(false);
 
-        l->addWidget(_name);
+        vl->addWidget(_name);
 
         _time = new DLabel(this);
         DFontSizeManager::instance()->bind(_time, DFontSizeManager::T9);
@@ -132,8 +166,9 @@ public:
             setState(ItemState::Invalid);
             _time->setText(tr("The file does not exist"));
         }
-        l->addStretch();
+        vl->addStretch();
         l->addWidget(_time);
+        l->addSpacing(10);
 
         _closeBtn = new DFloatingButton(DStyle::SP_CloseButton, this);
         _closeBtn->setFocusPolicy(Qt::NoFocus);
@@ -149,7 +184,11 @@ public:
         auto t = new Tip(QPixmap(), _pif.mi.title, nullptr);
         t->setWindowFlags(Qt::ToolTip | Qt::CustomizeWindowHint);
         t->setText(_pif.mi.title);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         t->resetSize(QApplication::desktop()->availableGeometry().width());
+#else
+        t->resetSize(QGuiApplication::primaryScreen()->availableGeometry().width());
+#endif
         t->setAttribute(Qt::WA_TranslucentBackground);
         t->setProperty("for", QVariant::fromValue<QWidget *>(this));
         t->layout()->setContentsMargins(5, 10, 5, 10);
@@ -157,13 +196,48 @@ public:
         setProperty("HintWidget", QVariant::fromValue<QWidget *>(t));
         if (!utils::check_wayland_env())
             installEventFilter(th);
-//        connect(_playlist, &PlaylistWidget::sizeChange, this, &PlayItemWidget::slotSizeChange);
+        connect(_playlist, &PlaylistWidget::sizeChange, this, &PlayItemWidget::slotSizeChange);
 
         m_opacityEffect = new QGraphicsOpacityEffect;
         _time->setGraphicsEffect(m_opacityEffect);
         m_opacityEffect_1 = new QGraphicsOpacityEffect;
         _index->setGraphicsEffect(m_opacityEffect_1);
         setState(ItemState::Normal);
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::CompactMode) {
+        setFixedHeight(24);
+        _closeBtn->setIconSize(QSize(18, 18));
+        _closeBtn->setFixedSize(17, 17);
+        _name->setFixedHeight(24);
+        if (_thumb)
+            _thumb->setFixedSize(28, 16);
+        else
+            m_pSvgWidget->setFixedSize(28, 16);
+    }
+
+    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::sizeModeChanged, this, [=](DGuiApplicationHelper::SizeMode sizeMode) {
+        if (sizeMode == DGuiApplicationHelper::NormalMode) {
+            setFixedHeight(36);
+            _closeBtn->setIconSize(QSize(28, 28));
+            _closeBtn->setFixedSize(25, 25);
+            _name->setFixedHeight(36);
+            if (_thumb)
+                _thumb->setFixedSize(42, 24);
+            else
+                m_pSvgWidget->setFixedSize(42, 24);
+        } else {
+            setFixedHeight(24);
+            _closeBtn->setIconSize(QSize(18, 18));
+            _closeBtn->setFixedSize(17, 17);
+            _name->setFixedHeight(24);
+            if (_thumb)
+                _thumb->setFixedSize(28, 16);
+            else
+                m_pSvgWidget->setFixedSize(28, 16);
+        }
+        updateClosePosition();
+    });
+#endif
     }
     
     ~PlayItemWidget() override
@@ -258,6 +332,9 @@ public:
         }
         if (!_pif.url.isLocalFile() || _pif.info.exists()) {
             emit doubleClicked();
+        }else{
+            //fixed:影院循环播放10个smb上的视频一段时间后，点击播放按钮或点击列表中的视频没反应
+            emit _playlist->engine()->sigInvalidFile(QFileInfo(_pif.url.toLocalFile()).fileName());
         }
     }
 
@@ -273,7 +350,7 @@ private slots:
             if (_thumb) {
                 _thumb->setPic(_pif.thumbnail);
             } else {
-                //m_pSvgWidget->load(QString(":/resources/icons/music-light.svg"));
+                m_pSvgWidget->load(QString(":/resources/icons/music-light.svg"));
             }
 //            pa.setColor(QPalette::BrightText, Qt::black);
 //            _name->setPalette(pa);
@@ -284,7 +361,7 @@ private slots:
             if (_thumb) {
                 _thumb->setPic(_pif.thumbnail_dark);
             } else {
-                //m_pSvgWidget->load(QString(":/resources/icons/music-dark.svg"));
+                m_pSvgWidget->load(QString(":/resources/icons/music-dark.svg"));
             }
 //            pa.setColor(QPalette::BrightText, Qt::white);
 //            _name->setPalette(pa);
@@ -294,7 +371,7 @@ private slots:
     }
     void slotSizeChange()
     {
-        setFixedWidth(_playlist->width());
+        setFixedWidth(_playlist->width() - 230);
     }
 
 protected:
@@ -316,6 +393,7 @@ protected:
             pa.setColor(QPalette::Text, Qt::white);
             _name->setPalette(pa);
             _index->setPalette(pa);
+            update();
         } else {
             if (state() == ItemState::Playing) {
                 _name->setForegroundRole(DPalette::Highlight);
@@ -346,6 +424,7 @@ protected:
 
         QFrame::leaveEvent(e);
     }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     void enterEvent(QEvent *e) override
     {
         _closeBtn->show();
@@ -356,6 +435,18 @@ protected:
 
         QFrame::enterEvent(e);
     }
+#else
+    void enterEvent(QEnterEvent *e) override
+    {
+        _closeBtn->show();
+        _closeBtn->raise();
+
+        updateClosePosition();
+        setHovered(true);
+
+        QFrame::enterEvent(e);
+    }
+#endif
     bool eventFilter(QObject *obj, QEvent *e) override
     {
         if (e->type() == QEvent::MouseButtonDblClick) {
@@ -367,16 +458,13 @@ protected:
     void resizeEvent(QResizeEvent *re) override
     {
         updateClosePosition();
+        _name->setFixedWidth(width() - 180);
         updateNameText();
 
         QFrame::resizeEvent(re);
     }
     bool event(QEvent *ee) override
     {
-        if (ee->type() == QEvent::Resize) {
-            _name->setFixedHeight(36);
-        }
-
         if (ee->type() == QEvent::Move) {
         }
 
@@ -384,10 +472,9 @@ protected:
     }
     void updateNameText()
     {
-        _name->setText(utils::ElideText(_pif.mi.title, {width() - 104, 36}, QTextOption::NoWrap,
-                                        _name->font(), Qt::ElideRight, 18, width() - 104));
+        _name->setText(utils::ElideText(_pif.mi.title, {width() - 242, 36}, QTextOption::NoWrap,
+                                        _name->font(), Qt::ElideRight, 18, width() - 242));
         _name->setCursor(Qt::ArrowCursor);
-        _name->setFixedHeight(36);
     }
     void showEvent(QShowEvent *se) override
     {
@@ -422,7 +509,11 @@ protected:
         }
 
         if (_hovered) {
-            DPalette pa = DApplicationHelper::instance()->palette(this);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+            DPalette pa = DGuiApplicationHelper::instance()->palette(this);
+#else
+            DPalette pa = DGuiApplicationHelper::instance()->applicationPalette();
+#endif
             pa.setBrush(DPalette::Text, pa.color(DPalette::Highlight));
             QColor bgColor(255, 255, 255, static_cast<int>(255 * 0.05));
             if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
@@ -577,32 +668,40 @@ PlaylistWidget::PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
     : QWidget(mw), _engine(mpv), _mw(static_cast<MainWindow *>(mw))
 {
     bool composited = CompositingManager::get().composited();
-//    setAttribute(Qt::WA_TranslucentBackground, false);
+    setAttribute(Qt::WA_TranslucentBackground, false);
     this->setObjectName(PLAYLIST_WIDGET);
 
     paOpen = nullptr;
     paClose = nullptr;
     pSelectItemWgt = nullptr;
 
-    setFixedWidth(344);
     QVBoxLayout *mainVLayout = new QVBoxLayout(this);
-    mainVLayout->setContentsMargins(0, 20, 0, 0);
+    mainVLayout->setContentsMargins(0, 0, 0, 0);
     mainVLayout->setSpacing(0);
     setLayout(mainVLayout);
 
-    QVBoxLayout *leftLayout = new QVBoxLayout;
-    leftLayout->setContentsMargins(0, 0, 0, 0);
-    leftLayout->setSpacing(0);
+    QHBoxLayout *mainLayout = new QHBoxLayout();
+    mainLayout->setContentsMargins(10, 0, 10, 0);
+    mainLayout->setSpacing(0);
+    mainLayout->setAlignment(Qt::AlignLeft | Qt::AlignTop);
 
-    QHBoxLayout *topLayout = new QHBoxLayout;
-    topLayout->setContentsMargins(0, 0, 20, 0);
-    topLayout->setSpacing(0);
+    QWidget *topspec = new QWidget;
+    topspec->setFixedHeight(20);
+
+    mainVLayout->addWidget(topspec);
+    mainVLayout->addLayout(mainLayout);
+
+    QWidget *left = new QWidget();
+    left->setObjectName(LEFT_WIDGET);
+    left->setFixedSize(197, 288);
+    left->setContentsMargins(0, 0, 0, 0);
+    left->setAttribute(Qt::WA_TranslucentBackground, false);
+    left->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred));
 
     _title = new DLabel();
-    DFontSizeManager::instance()->bind(_title, DFontSizeManager::T4);
+    DFontSizeManager::instance()->bind(_title, DFontSizeManager::T3);
     _title->setForegroundRole(DPalette::ToolTipText);
     _title->setText(tr("Playlist"));
-    _title->setContentsMargins(20, 0, 0, 0);
 
     _num = new DLabel();
     _num->setForegroundRole(DPalette::BrightText);
@@ -611,38 +710,88 @@ PlaylistWidget::PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
     opacityEffect->setOpacity(0.5);
     _num->setText("");
     DFontSizeManager::instance()->bind(_num, DFontSizeManager::T6);
-    _num->setContentsMargins(20, 0, 0, 0);
+    _num->setContentsMargins(0, 0, 0, 0);
 
-    m_pClearButton = new DToolButton(this);
-    m_pClearButton->setIcon(QIcon::fromTheme("dcc_clearlist"));
+    mainLayout->addWidget(left);
+    auto *leftinfo = new QVBoxLayout;
+    leftinfo->setContentsMargins(0, 0, 0, 0);
+    leftinfo->setSpacing(0);
+    left->setLayout(leftinfo);
+    leftinfo->setAlignment(Qt::AlignLeft | Qt::AlignTop);
+    leftinfo->addWidget(_title);
+    leftinfo->addSpacing(4);
+    leftinfo->addWidget(_num);
+    leftinfo->addSpacing(6);
+
+    m_pClearButton = new DPushButton();
     m_pClearButton->setObjectName(CLEAR_PLAYLIST_BUTTON);
     m_pClearButton->setAccessibleName(CLEAR_PLAYLIST_BUTTON);
+    m_pClearButton->setIcon(QIcon::fromTheme("dcc_clearlist"));
+    m_pClearButton->setText(tr("Empty"));
     m_pClearButton->setFocusPolicy(Qt::TabFocus);
     m_pClearButton->installEventFilter(this);
-    connect(m_pClearButton, &DToolButton::clicked, _engine, &PlayerEngine::clearPlaylist);
+    DFontSizeManager::instance()->bind(m_pClearButton, DFontSizeManager::T6);
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    DPalette pa_cb = DGuiApplicationHelper::instance()->palette(m_pClearButton);
+#else
+    DPalette pa_cb = DGuiApplicationHelper::instance()->applicationPalette();
+#endif
+    if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
+        pa_cb.setBrush(QPalette::Light, QColor(100, 100, 100, 255));
+        pa_cb.setBrush(QPalette::Dark, QColor(92, 92, 92, 255));
+    } else {
+        pa_cb.setBrush(QPalette::Light, QColor(85, 84, 84, 255));
+        pa_cb.setBrush(QPalette::Dark, QColor(65, 65, 65, 255));
+    }
+    pa_cb.setBrush(QPalette::ButtonText, QColor(255, 255, 255, 255));
+    m_pClearButton->setPalette(pa_cb);
+    m_pClearButton->setContentsMargins(0, 0, 0, 0);
 
-    leftLayout->addWidget(_title);
-    leftLayout->addStretch(5);
-    leftLayout->addWidget(_num);
-    leftLayout->addStretch(10);
-    topLayout->addLayout(leftLayout);
-    topLayout->addWidget(m_pClearButton);
-    mainVLayout->addLayout(topLayout);
+    QObject::connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::paletteTypeChanged, m_pClearButton, [ = ]() {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+        DPalette pa_cBtn = DGuiApplicationHelper::instance()->palette(m_pClearButton);
+#else
+        DPalette pa_cBtn = DGuiApplicationHelper::instance()->applicationPalette();
+#endif
+        if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
+            pa_cBtn.setBrush(QPalette::Light, QColor(100, 100, 100, 255));
+            pa_cBtn.setBrush(QPalette::Dark, QColor(92, 92, 92, 255));
+        } else {
+            pa_cBtn.setBrush(QPalette::Light, QColor(85, 84, 84, 255));
+            pa_cBtn.setBrush(QPalette::Dark, QColor(65, 65, 65, 255));
+        }
+        m_pClearButton->setPalette(pa_cb);
+    });
+
+    leftinfo->addWidget(m_pClearButton);
+    connect(m_pClearButton, &QPushButton::clicked, _engine, &PlayerEngine::clearPlaylist);
+
+    left->setContentsMargins(36, 0, 0, 0);
+    m_pClearButton->setContentsMargins(0, 0, 0, 70);
+    _num->setContentsMargins(0, 0, 0, 0);
+
+    QWidget *right = new QWidget();
+    right->setObjectName(RIGHT_LIST_WIDGET);
+    auto *rightinfo = new QVBoxLayout;
+    rightinfo->setContentsMargins(0, 0, 0, 0);
+    rightinfo->setSpacing(0);
+    right->setLayout(rightinfo);
+    right->setContentsMargins(0, 0, 0, 0);
+    mainLayout->addWidget(right);
 
     _playlist = new DListWidget();
     _playlist->setAttribute(Qt::WA_DeleteOnClose);
-    _playlist->setFixedSize(334, 440);
+    _playlist->setFixedSize(width() - 205, 288);
     _playlist->setContentsMargins(0, 0, 0, 0);
     _playlist->installEventFilter(this);
     _playlist->viewport()->setAutoFillBackground(false);
     _playlist->setAutoFillBackground(false);
     _playlist->setObjectName(PLAYLIST);
     _playlist->viewport()->setObjectName(FILE_LIST);
-    _playlist->setParent(this);
 
-    mainVLayout->addWidget(_playlist);
-//    _playlist->setAttribute(Qt::WA_TranslucentBackground, false);
+    rightinfo->addWidget(_playlist);
+    _playlist->setAttribute(Qt::WA_TranslucentBackground, false);
     _playlist->setFrameShape(QFrame::NoFrame);
     _playlist->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred));
     _playlist->setSelectionMode(QListView::NoSelection);
@@ -661,6 +810,8 @@ PlaylistWidget::PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
     connect(_playlist, &DListWidget::itemClicked, this, &PlaylistWidget::slotShowSelectItem);
     connect(_playlist, &DListWidget::currentItemChanged, this, &PlaylistWidget::OnItemChanged);
 
+    _playlist->setContentsMargins(0, 0, 0, 0);
+
     if (!composited) {
         _playlist->setWindowFlags(Qt::FramelessWindowHint | Qt::BypassWindowManagerHint);
         _playlist->setAttribute(Qt::WA_NativeWindow);
@@ -675,18 +826,48 @@ PlaylistWidget::PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
 
     if (!_closeMapper) {
         _closeMapper = new QSignalMapper(this);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         connect(_closeMapper,
-                static_cast<void(QSignalMapper::*)(QWidget *)>(&QSignalMapper::mapped), this, &PlaylistWidget::slotCloseItem);
-
+                static_cast<void(QSignalMapper::*)(QWidget *)>(&QSignalMapper::mapped), 
+                this, &PlaylistWidget::slotCloseItem);
+#else
+        connect(_closeMapper, &QSignalMapper::mappedObject,
+                this, [this](QObject *obj) {
+                    slotCloseItem(qobject_cast<QWidget *>(obj));
+                });
+#endif
     }
 
     if (!_activateMapper) {
         _activateMapper = new QSignalMapper(this);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         connect(_activateMapper,
-                static_cast<void(QSignalMapper::*)(QWidget *)>(&QSignalMapper::mapped), this, &PlaylistWidget::slotDoubleClickedItem);
-
+                static_cast<void(QSignalMapper::*)(QWidget *)>(&QSignalMapper::mapped), 
+                this, &PlaylistWidget::slotDoubleClickedItem);
+#else
+        connect(_activateMapper, &QSignalMapper::mappedObject,
+                this, [this](QObject *obj) {
+                    slotDoubleClickedItem(qobject_cast<QWidget *>(obj));
+                });
+#endif
     }
 
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::sizeModeChanged, this, [=](DGuiApplicationHelper::SizeMode sizeMode) {
+        if (sizeMode == DGuiApplicationHelper::NormalMode) {
+            for (int i = 0; i < _playlist->count(); i++) {
+                QListWidgetItem *item = _playlist->item(i);
+                item->setSizeHint(QSize(_playlist->itemWidget(item)->width(), 36));
+            }
+        } else {
+            for (int i = 0; i < _playlist->count(); i++) {
+                QListWidgetItem *item = _playlist->item(i);
+                item->setSizeHint(QSize(_playlist->itemWidget(item)->width(), 24));
+            }
+        }
+    });
+#endif
+
     connect(&_engine->playlist(), &PlaylistModel::emptied, this, &PlaylistWidget::clear);
     connect(&_engine->playlist(), &PlaylistModel::itemsAppended, this, &PlaylistWidget::appendItems);
     connect(&_engine->playlist(), &PlaylistModel::itemRemoved, this, &PlaylistWidget::removeItem);
@@ -704,6 +885,7 @@ PlaylistWidget::PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
         });
     });
     connect(ActionFactory::get().playlistContextMenu(), &DMenu::aboutToHide, [ = ]() {
+        m_pClearButton->update();
         if (_mouseItem) {
             (static_cast<PlayItemWidget *>(_mouseItem))->setHovered(false);
         }
@@ -907,14 +1089,78 @@ void PlaylistWidget::slotRowsMoved()
     }
 }
 
+/*void PlaylistWidget::dragEnterEvent(QDragEnterEvent *ev)
+{
+    auto md = ev->mimeData();
+    qInfo() << md->formats();
+    if (md->formats().contains("application/x-qabstractitemmodeldatalist")) {
+        if (!_playlist->selectedItems().contains(_playlist->itemAt(ev->pos()))) {
+            _playlist->setDropIndicatorShown(true);
+        }
+        QWidget::dragEnterEvent(ev);
+        return;
+    }
+
+    if (ev->mimeData()->hasUrls()) {
+        ev->acceptProposedAction();
+    }
+}*/
+
+/*void PlaylistWidget::dragMoveEvent(QDragMoveEvent *ev)
+{
+    auto md = ev->mimeData();
+    if (md->formats().contains("application/x-qabstractitemmodeldatalist")) {
+        if (!_playlist->selectedItems().contains(_playlist->itemAt(ev->pos()))) {
+            _playlist->setDropIndicatorShown(true);
+        }
+        QWidget::dragMoveEvent(ev);
+        return;
+    }
+
+    if (ev->mimeData()->hasUrls()) {
+        ev->acceptProposedAction();
+    }
+}*/
+
+/*void PlaylistWidget::dropEvent(QDropEvent *ev)
+{
+    auto md = ev->mimeData();
+    if (md->formats().contains("application/x-qabstractitemmodeldatalist")) {
+        _playlist->setDropIndicatorShown(false);
+        auto encoded = md->data("application/x-qabstractitemmodeldatalist");
+        QDataStream stream(&encoded, QIODevice::ReadOnly);
+
+        QList<int> l;
+        while (!stream.atEnd()) {
+            int row, col;
+            QMap<int,  QVariant> roleDataMap;
+            stream >> row >> col >> roleDataMap;
+            auto piw = dynamic_cast<PlayItemWidget *>(_playlist->itemWidget(_playlist->item(row)));
+            _lastDragged = qMakePair(row, piw);
+            qInfo() << "drag to move " << row << piw->_pif.url;
+        }
+
+        QWidget::dropEvent(ev);
+        return;
+    }
+
+    if (!ev->mimeData()->hasUrls()) {
+        return;
+    }
+    auto urls = ev->mimeData()->urls();
+    _engine->addPlayFiles(urls);
+
+    ev->acceptProposedAction();
+}*/
+
 void PlaylistWidget::contextMenuEvent(QContextMenuEvent *cme)
 {
     bool on_item = false;
     _mouseItem = nullptr;
-    QPoint globaPoint = _playlist->mapFromParent(cme->pos());
+    QPoint itempos(cme->pos().x() - 235, cme->pos().y() - 20);
 
-    if (_playlist->itemAt(globaPoint)) {
-        _mouseItem = _playlist->itemWidget(_playlist->itemAt(globaPoint));
+    if (_playlist->itemAt(itempos)) {
+        _mouseItem = _playlist->itemWidget(_playlist->itemAt(itempos));
         on_item = true;
     }
 
@@ -1145,11 +1391,30 @@ void PlaylistWidget::togglePopup(bool isShortcut)
     QRect view_rect = main_rect.marginsRemoved(QMargins(1, 1, 1, 1));
 #endif
 
-    QRect fixed(view_rect.width() - width() - 10, 60, 344, view_rect.height() - 138);
+    int toolbox_height = TOOLBOX_HEIGHT;
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::CompactMode) {
+        toolbox_height = TOOLBOX_DSIZEMODE_HEIGHT;
+    }
+#endif
+
+/**
+ * 此处在动画执行前设定好PlaylistWidget的起始位置和终止位置
+ * 基于 MainWindow::updateProxyGeometry所设置的初始状态 以及 是否是紧凑模式 定位PlaylistWidget的起始位置和终止位置。
+*/
+    QRect fixed;
+    if(CompositingManager::get().platform() == X86) {
+        fixed.setRect(10, (view_rect.height() - (TOOLBOX_SPACE_HEIGHT + toolbox_height + 10)),
+                      view_rect.width() - 20, TOOLBOX_SPACE_HEIGHT + 10);
+    }
+    else {
+        fixed.setRect(10, (view_rect.height() - (TOOLBOX_SPACE_HEIGHT + toolbox_height + 10) + 5),
+                      view_rect.width() - 20, TOOLBOX_SPACE_HEIGHT + 10);
+    }
 
     QRect shrunk = fixed;
-    shrunk.setWidth(0);
-    shrunk.moveRight(fixed.right());
+    shrunk.setHeight(0);
+    shrunk.moveBottom(fixed.bottom());
 
     if (_toggling) return;
 
@@ -1222,12 +1487,7 @@ void PlaylistWidget::paintEvent(QPaintEvent *pe)
     bgRect.setSize(size());
     QPainterPath pp;
     pp.addRoundedRect(bgRect, 18, 18);
-    if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType())
-        painter.setBrush(QBrush(QColor(238, 238, 238, 0.8 * 255)));
-    else
-        painter.setBrush(QBrush(QColor(32, 32, 32, 0.9 * 255)));
-    painter.setPen(Qt::NoPen);
-    painter.drawPath(pp);
+    QWidget::paintEvent(pe);
 }
 
 void PlaylistWidget::resizeEvent(QResizeEvent *ev)
@@ -1238,8 +1498,9 @@ void PlaylistWidget::resizeEvent(QResizeEvent *ev)
 #else
     auto view_rect = main_rect.marginsRemoved(QMargins(1, 1, 1, 1));
 #endif
-//    _playlist->setFixedWidth(fixed.width() - 205);
-    _playlist->setFixedHeight(view_rect.height() - 102);
+    QRect fixed((view_rect.width() - 10), (view_rect.height() - 394),
+                view_rect.width() - 20, (384 - 70));
+    _playlist->setFixedWidth(fixed.width() - 205);
     emit sizeChange();
 
     QTimer::singleShot(100, this, &PlaylistWidget::batchUpdateSizeHints);
@@ -1267,8 +1528,6 @@ bool PlaylistWidget::eventFilter(QObject *obj, QEvent *event)
                 return true;
             }
             break;
-        default:
-            break;
         }
     } else if (obj == _playlist) {
         switch (event->type()) {
