@@ -3,10 +3,6 @@
 <TS version="2.1" language="lt">
 <context>
     <name>MircastShowWidget</name>
-    <message>
-        <source>Exit Miracast</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Projecting... 
 Please do not exit the Movie app during the process.</source>
@@ -16,6 +12,10 @@ Please do not exit the Movie app during the process.</source>
         <source>Display device</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Exit Miracast</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MircastWidget</name>
@@ -270,6 +270,27 @@ Please do not exit the Movie app during the process.</source>
         <source>Software decoding</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Customize</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Decode mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video out</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The custom decoding method needs to be restarted before it can take effect,
+and whether to restart it?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendering engine</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UrlDialog</name>
@@ -324,6 +345,34 @@ Please do not exit the Movie app during the process.</source>
         <source>Open CD/DVD</source>
         <translation>Atverti CD/DVD</translation>
     </message>
+    <message>
+        <source>Mini Mode</source>
+        <translation>Minimali veiksena</translation>
+    </message>
+    <message>
+        <source>Play Mode</source>
+        <translation>Atkūrimo veiksena</translation>
+    </message>
+    <message>
+        <source>Order Play</source>
+        <translation>Tvarkingas atkūrimas</translation>
+    </message>
+    <message>
+        <source>Shuffle Play</source>
+        <translation>Maišytas atkūrimas</translation>
+    </message>
+    <message>
+        <source>Single Play</source>
+        <translation>Pavienis atkūrimas</translation>
+    </message>
+    <message>
+        <source>Single Loop</source>
+        <translation>Pavienio kartojimas</translation>
+    </message>
+    <message>
+        <source>List Loop</source>
+        <translation>Sąrašo kartojimas</translation>
+    </message>
     <message>
         <source>Frame</source>
         <translation>Kadras</translation>
@@ -372,10 +421,18 @@ Please do not exit the Movie app during the process.</source>
         <source>Load</source>
         <translation>Įkelti</translation>
     </message>
+    <message>
+        <source>Online Search</source>
+        <translation>Ieškoti internete</translation>
+    </message>
     <message>
         <source>Select</source>
         <translation>Pasirinkti</translation>
     </message>
+    <message>
+        <source>Hide</source>
+        <translation>Slėpti</translation>
+    </message>
     <message>
         <source>Encodings</source>
         <translation>Koduotės</translation>
@@ -384,10 +441,22 @@ Please do not exit the Movie app during the process.</source>
         <source>Screenshot</source>
         <translation>Ekrano kopija</translation>
     </message>
+    <message>
+        <source>Film Screenshot</source>
+        <translation>Filmo ekrano kopija</translation>
+    </message>
+    <message>
+        <source>Burst Shooting</source>
+        <translation>Pliūpsnis ekrano kopijų</translation>
+    </message>
     <message>
         <source>Playlist</source>
         <translation>Grojaraštis</translation>
     </message>
+    <message>
+        <source>Film Info</source>
+        <translation>Filmo informacija</translation>
+    </message>
     <message>
         <source>Delete from playlist</source>
         <translation>Ištrinti iš grojaraščio</translation>
@@ -396,10 +465,22 @@ Please do not exit the Movie app during the process.</source>
         <source>Display in file manager</source>
         <translation>Rodyti failų tvarkytuvėje</translation>
     </message>
+    <message>
+        <source>Next Frame</source>
+        <translation>Kitas kadras</translation>
+    </message>
+    <message>
+        <source>Previous Frame</source>
+        <translation>Ankstesnis kadras</translation>
+    </message>
     <message>
         <source>Open screenshot folder</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Playback Speed</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>0.5x</source>
         <translation type="unfinished"></translation>
@@ -420,70 +501,6 @@ Please do not exit the Movie app during the process.</source>
         <source>2.0x</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Play</source>
-        <translation type="unfinished">Groti</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation type="unfinished">Ankstesnis</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation type="unfinished">Kitas</translation>
-    </message>
-    <message>
-        <source>Order play</source>
-        <translation type="unfinished">Tvarkingas atkūrimas</translation>
-    </message>
-    <message>
-        <source>Shuffle play</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Single play</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Single loop</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>List loop</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation type="unfinished">Kitas kadras</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation type="unfinished">Ankstesnis kadras</translation>
-    </message>
-    <message>
-        <source>Playback speed</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Mini mode</source>
-        <translation type="unfinished">Minimali veiksena</translation>
-    </message>
-    <message>
-        <source>Online search</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Film screenshot</source>
-        <translation type="unfinished">Filmo ekrano kopija</translation>
-    </message>
-    <message>
-        <source>Burst shooting</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>None</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>dmr::BurstScreenshotsDialog</name>
@@ -566,6 +583,14 @@ Please do not exit the Movie app during the process.</source>
         <source>Speed: %1x</source>
         <translation>Greitis: %1x</translation>
     </message>
+    <message>
+        <source>View</source>
+        <translation>Žiūrėti</translation>
+    </message>
+    <message>
+        <source>Saved to</source>
+        <translation>Įrašyta į</translation>
+    </message>
     <message>
         <source>The screenshot is saved</source>
         <translation>Ekrano kopija įrašyta</translation>
@@ -594,6 +619,10 @@ Please do not exit the Movie app during the process.</source>
         <source>No video file found</source>
         <translation>Nerasta jokio vaizdo įrašo failo</translation>
     </message>
+    <message>
+        <source>Film screenshot</source>
+        <translation>Filmo ekrano kopija</translation>
+    </message>
     <message>
         <source>Taking the screenshots, please wait...</source>
         <translation>Daromos ekrano kopijos, palaukite...</translation>
@@ -675,12 +704,13 @@ Please do not exit the Movie app during the process.</source>
         <source>Miracast disconnected</source>
         <translation type="unfinished"></translation>
     </message>
-</context>
-<context>
-    <name>dmr::MessageWindow</name>
     <message>
-        <source>View</source>
-        <translation type="obsolete">Žiūrėti</translation>
+        <source>Cancel</source>
+        <translation type="unfinished">Atsisakyti</translation>
+    </message>
+    <message>
+        <source>Restart</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -716,6 +746,10 @@ Please do not exit the Movie app during the process.</source>
         <source>Duration</source>
         <translation>Trukmė</translation>
     </message>
+    <message>
+        <source>Type</source>
+        <translation>Tipas</translation>
+    </message>
     <message>
         <source>Size</source>
         <translation>Dydis</translation>
@@ -796,14 +830,6 @@ Please do not exit the Movie app during the process.</source>
         <source>%1 bps</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Name</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Format</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>dmr::MpvProxy</name>
@@ -879,6 +905,18 @@ Please do not exit the Movie app during the process.</source>
         <comment>All (*)</comment>
         <translation type="unfinished">Subtitrai (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
     </message>
+    <message>
+        <source>View</source>
+        <translation type="unfinished">Žiūrėti</translation>
+    </message>
+    <message>
+        <source>Film screenshot</source>
+        <translation type="unfinished">Filmo ekrano kopija</translation>
+    </message>
+    <message>
+        <source>Saved to</source>
+        <translation type="unfinished">Įrašyta į</translation>
+    </message>
     <message>
         <source>The screenshot is saved</source>
         <translation type="unfinished">Ekrano kopija įrašyta</translation>
@@ -983,12 +1021,13 @@ Please do not exit the Movie app during the process.</source>
         <source>Miracast disconnected</source>
         <translation type="unfinished"></translation>
     </message>
-</context>
-<context>
-    <name>dmr::Platform_MessageWindow</name>
     <message>
-        <source>View</source>
-        <translation type="obsolete">Žiūrėti</translation>
+        <source>Cancel</source>
+        <translation type="unfinished">Atsisakyti</translation>
+    </message>
+    <message>
+        <source>Restart</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1004,6 +1043,10 @@ Please do not exit the Movie app during the process.</source>
         <source>Playlist</source>
         <translation type="unfinished">Grojaraštis</translation>
     </message>
+    <message>
+        <source>Empty</source>
+        <translation type="unfinished">Išvalyti</translation>
+    </message>
     <message>
         <source>%1 videos</source>
         <translation type="unfinished"></translation>
@@ -1016,21 +1059,17 @@ Please do not exit the Movie app during the process.</source>
         <translation type="unfinished">Groti/Pristabdyti</translation>
     </message>
     <message>
-        <source>15s backward</source>
-        <translation type="unfinished">0.5 sek. atgal {15s?}</translation>
+        <source>Previous</source>
+        <translation type="unfinished">Ankstesnis</translation>
     </message>
     <message>
-        <source>15s forward</source>
-        <translation type="unfinished">0.5 sek. pirmyn {15s?}</translation>
+        <source>Next</source>
+        <translation type="unfinished">Kitas</translation>
     </message>
     <message>
         <source>Fullscreen</source>
         <translation type="unfinished">Visas ekranas</translation>
     </message>
-    <message>
-        <source>Miracast</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Playlist</source>
         <translation type="unfinished">Grojaraštis</translation>
@@ -1047,6 +1086,10 @@ Please do not exit the Movie app during the process.</source>
         <source>Play</source>
         <translation type="unfinished">Groti</translation>
     </message>
+    <message>
+        <source>Miracast</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>dmr::PlayItemWidget</name>
@@ -1065,6 +1108,10 @@ Please do not exit the Movie app during the process.</source>
         <source>%1 videos</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Empty</source>
+        <translation>Išvalyti</translation>
+    </message>
 </context>
 <context>
     <name>dmr::Settings</name>
@@ -1111,6 +1158,14 @@ Please do not exit the Movie app during the process.</source>
         <source>Play</source>
         <translation>Groti</translation>
     </message>
+    <message>
+        <source>Previous</source>
+        <translation>Ankstesnis</translation>
+    </message>
+    <message>
+        <source>Next</source>
+        <translation>Kitas</translation>
+    </message>
     <message>
         <source>Playlist</source>
         <translation>Grojaraštis</translation>
@@ -1131,17 +1186,20 @@ Please do not exit the Movie app during the process.</source>
         <source>Pause</source>
         <translation>Pristabdyti</translation>
     </message>
-    <message>
-        <source>15s backward</source>
-        <translation type="unfinished">0.5 sek. atgal {15s?}</translation>
-    </message>
-    <message>
-        <source>15s forward</source>
-        <translation type="unfinished">0.5 sek. pirmyn {15s?}</translation>
-    </message>
     <message>
         <source>Miracast</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Volume</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>dmr::VolumeButton</name>
+    <message>
+        <source>Volume</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
